@@ -36,7 +36,7 @@ module Neovim
     def shutdown
       @running = false
       @shutdown = true
-      run
+      @connection.close
     end
 
     def request(request_id, method, *args)
@@ -70,20 +70,23 @@ module Neovim
 
     def run
       @running = true
+      last_value = nil
 
       loop do
         break unless @running
         break if @shutdown
 
         begin
-          yield read
-        rescue EOFError => e
+          last_value = yield(read)
+        rescue EOFError, Errno::EPIPE => e
           log_exception(:debug, e, __method__)
           shutdown
         rescue => e
           log_exception(:error, e, __method__)
         end
       end
+
+      last_value
     ensure
       @connection.close if @shutdown
     end
