@@ -7,9 +7,9 @@ set -eu
 case "$(echo "$RUNNER_OS" | tr "[:upper:]" "[:lower:]")" in
   macos)
     wget -nv -P /tmp \
-      "https://github.com/neovim/neovim/releases/download/stable/nvim-macos.tar.gz"
-    tar -C /tmp -xzf /tmp/nvim-macos.tar.gz
-    mv /tmp/nvim-macos ./_nvim
+      "https://github.com/neovim/neovim/releases/download/stable/nvim-macos-x86_64.tar.gz"
+    tar -C /tmp -xzf /tmp/nvim-macos-x86_64.tar.gz
+    mv /tmp/nvim-macos-x86_64 ./_nvim
     ;;
   linux)
     mkdir -p _nvim/bin
